# CrateDB django connector.

Connector to use CrateDB as a database in Django ORM.

# Documentation

## How to install
uv
```shell
uv pip add cratedb_django
```
pipx
```shell
pipx install cratedb_django
```


### Environment variables
SUPPRESS_UNIQUE_CONSTRAINT_WARNING [true/false] Suppresses warning when a model is created with unique=True constraint.

# License
This project is open-source under a MIT license.